import { dev } from "$app/environment";
import { base } from "$app/paths";
import type { Handle, RequestEvent } from "@sveltejs/kit";
import type { Cookie as LuciaCookie } from "lucia";

export function setLuciaCookie(event: RequestEvent, cookie: LuciaCookie) {
  event.cookies.set(cookie.name, cookie.value, {
    path: ".",
    ...cookie.attributes,
  });
}

export function setTempCookie(
  event: RequestEvent,
  name: string,
  value: string,
) {
  event.cookies.set(name, value, {
    path: "/",
    secure: !dev,
    httpOnly: true,
    maxAge: 60 * 10,
    sameSite: "lax",
  });
}

export function route(pathname: string, handler: Handle): Handle {
  return ({ event, resolve }) => {
    if (event.url.pathname === pathname) {
      return handler({ event, resolve });
    }

    return resolve(event);
  };
}

export function method(method: string, handler: Handle): Handle {
  return ({ event, resolve }) => {
    if (event.request.method === method) {
      return handler({ event, resolve });
    }

    return resolve(event);
  };
}

export function addBasePath(path: string): string {
  return `${base}${path}`;
}
